#
# spec file for package python-azure-mgmt-compute
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-mgmt-compute
Version:        34.0.0
Release:        1.1
Summary:        Microsoft Azure Compute Management Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure_mgmt_compute/azure_mgmt_compute-%{version}.tar.gz
BuildRequires:  %{python_module azure-mgmt-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-mgmt-nspkg >= 3.0.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-typing_extensions >= 4.6.0
Requires:       (python-azure-common >= 1.1 with python-azure-common < 2.0.0)
Requires:       (python-azure-mgmt-core >= 1.3.2 with python-azure-mgmt-core < 2.0.0)
Requires:       (python-isodate >= 0.6.1 with python-isodate < 1.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-mgmt-compute < 30.5.0
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Compute Management Client Library.

Azure Resource Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.5, 3.6 and 3.7.

%prep
%setup -q -n azure_mgmt_compute-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/mgmt/compute
%{python_sitelib}/azure_mgmt_compute-*.dist-info

%changelog
* Mon Jan 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 34.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Jan  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 33.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Adjust upstream source name in spec file
* Mon Aug 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 33.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Jul 25 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 32.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Drop extra LICENSE.txt as upstream now ships its own
- Rename LICENSE.txt to LICENSE in %%files section
- Update Requires from setup.py
* Mon Apr 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 31.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Apr  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Mon Jan 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Jan  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Oct  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Sep 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Mon Jul 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue May 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 30.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Jan 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 29.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Oct 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 29.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Oct  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 28.0.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Sep 22 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 28.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jun 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 27.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jun  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 27.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 27.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Mar  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 26.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Feb 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 26.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jan 28 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 25.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Jan 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 24.0.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jan  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 24.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Oct 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 23.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Sep  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 23.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jul 23 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 22.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jul  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 22.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Jun  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 21.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu May  6 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 20.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Mar 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 19.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Nov 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 18.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 17.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Jul 17 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 13.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Apr  2 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Mar 11 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 11.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
* Wed Nov 27 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 10.0.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.0.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + amc_drop-compatible-releases-operator.patch
  + amc_drop-extras-require.patch
- Update %%description from setup.py
* Thu Apr 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.4.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + amc_drop-extras-require.patch
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Refresh patches for new version
  + amc_drop-compatible-releases-operator.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update %%description from setup.py
- Update BuildRequires and Requires from setup.py
* Mon Sep  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.0.1
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Refresh patches for new version
  + amc_drop-compatible-releases-operator.patch
- Update Requires from setup.py
- Update %%description from setup.py
* Wed Apr 11 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 4.0.0rc1
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
  + amc_drop-compatible-releases-operator.patch
* Thu Jan 18 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 3.1.0rc3
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Install HISTORY.rst into doc directory
- Refresh patches for new version
  + amc_drop-compatible-releases-operator.patch
- Update Requires from setup.py
* Wed Oct  4 2017 adrian.glaubitz@suse.com
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Mon Oct  2 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 3.0.1
- Remove versioning for namespace packages in Requires
- Update Requires from setup.py
- Update Summary from README.rst
- Update %%description from README.rst
- Refresh patches for new version
  + amc_drop-compatible-releases-operator.patch
* Thu Jul 13 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
- Add python-azure-mgmt-nspkg to Requires
* Fri Jun 30 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 2.0.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + amc_drop-compatible-releases-operator.patch
